==> sagua_0.1.1-1.tar.gz: sagua-0.1.1/include/mixer.h <==
#ifndef GUARD_mixer_h
#define GUARD_mixer_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef HAVE_SYS_SOUNDCARD_H
#include <sys/soundcard.h>
#else
#ifdef HAVE_MACHINE_SOUNDCARD_H
#include <machine/soundcard.h>
#else
#ifdef HAVE_SOUNDCARD_H
#include <soundcard.h>
#endif
#endif
#endif

class MainManager;

class Mixer
{
    public:
	~Mixer() {};
	
	static Mixer* Create(const MainManager& mainManager)
	{
	    static Mixer mixer(mainManager);

	    return &mixer;
	}

	const double& GetVolumn();
	void SetVolumn(const double&);

    private:
	Mixer(const MainManager& mainManager):mainManager_(mainManager), currentPCMVolumn_(0.0) {}
	Mixer(const Mixer&);
	Mixer& operator=(const Mixer&);

	const MainManager& mainManager_;
	double currentPCMVolumn_;
};

#endif

==> sagua_0.2.3-1.tar.gz: sagua-0.2.3/include/mixer.h <==
#ifndef GUARD_mixer_h
#define GUARD_mixer_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file mixer.h
/// @brief Class for OSS mixer header file

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef HAVE_SYS_SOUNDCARD_H
#include <sys/soundcard.h>
#else
#ifdef HAVE_MACHINE_SOUNDCARD_H
#include <machine/soundcard.h>
#else
#ifdef HAVE_SOUNDCARD_H
#include <soundcard.h>
#endif
#endif
#endif

class MainManager;

/// @brief Class for OSS mixer
class Mixer
{
    public:
	~Mixer() {};
	
	/// @brief Create mixer object (singleton pattern)
	/// @param mainManager Program control MainManager
	/// @return Pointer of created mixer object
	static Mixer* Create(const MainManager& mainManager)
	{
	    static Mixer mixer(mainManager);

	    return &mixer;
	}

	const double& GetVolumn();
	void SetVolumn(const double&);

    private:
	Mixer(const MainManager& mainManager):mainManager_(mainManager), currentPCMVolumn_(0.0) {}
	Mixer(const Mixer&);
	Mixer& operator=(const Mixer&);

	const MainManager& mainManager_;    ///< Program control MainManager
	double currentPCMVolumn_;	    ///< Store current PCM volumn when call GetVolumn
};

#endif
